/* -*- C++ -*-
 * Euler - A watchy firmware for crazy people.
 *
 *  Copyright (c) 2021 Sameer Rahmani <lxsameer@gnu.org>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#include "Home.h"
#include <cstdio>

#define DARKMODE true

uint8_t Home::getBattery() {
  float VBAT = api.getBatteryVoltage();

  if (VBAT > 3.95 && VBAT <= 4.1) {
    return 2;
  }

  if (VBAT > 3.80 && VBAT <= 3.95) {
    return 1;
  }
  if (VBAT <= 3.80) {
    return 0;
  }

  return 3;
}

std::string Home::getAccel() {
  Accel acc;
  std::string s("");

  long previousMillis = 0;
  long interval = 200;

  // unsigned long currentMillis = millis();

  // if (currentMillis - previousMillis > interval) {
  //previousMillis = currentMillis;
    // Get acceleration data
    bool res = sensor.getAccel(acc);
    uint8_t direction = sensor.getDirection();
    if (res == false) {
      s = "FFF";
    } else {
      String dirc = "EEE";

      switch (direction) {
      case DIRECTION_DISP_DOWN:
        dirc = "F UP";

      case DIRECTION_DISP_UP:
        dirc = "F DN";
      case DIRECTION_BOTTOM_EDGE:
        dirc = "B ED";

      case DIRECTION_TOP_EDGE:
        dirc = "T ED";
      case DIRECTION_RIGHT_EDGE:
        dirc = "R ED";
      case DIRECTION_LEFT_EDGE:
        dirc = "L ED";
      }
      //sprintf(s, "X: %d Y: %d Z: %d\nD: %s", acc.x, acc.y, acc.z, dirc);
       std::ostringstream out;
       out << "X: " << acc.x << "\nY: " << acc.y << "\nZ: " << acc.z << "\nD: " << dirc;
       s = out.str();
       //s = std::format("X: {} Y: {} Z: {}\nD: {}", acc.x, acc.y, acc.z, dirc)
    }
    return s;
  // }

  // return "GGG";
}


void Home::draw() {
  api.display.setFont(&FreeMono12pt7b);
  api.display.setCursor(0, 0);
  api.display.print("\n");
  api.display.printf("%02d %02d %02d %02d 00\nB:%f\n%s",
                     api.currentTime.Month, api.currentTime.Day,
                     api.currentTime.Hour, api.currentTime.Minute,
                     api.getBatteryVoltage(),
                     getAccel().c_str());
  api.display.display(true);
};
